# Generated by Django 5.1.4 on 2025-02-23 08:14

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("cast", "0061_alter_audio_options"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="transcript",
            options={"ordering": ("-id",)},
        ),
    ]
