# Generated by Django 5.1.5 on 2025-02-04 10:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("cast", "0060_transcript"),
    ]

    operations = [
        migrations.AlterModelOptions(
            name="audio",
            options={"ordering": ("-created",)},
        ),
    ]
