# Generated by Django 5.0.6 on 2024-07-03 17:18

import cast.blocks
import wagtail.blocks
import wagtail.embeds.blocks
import wagtail.fields
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("cast", "0058_add_cover_image_to_blog"),
    ]

    operations = [
        migrations.AddField(
            model_name="blog",
            name="subtitle",
            field=models.CharField(
                blank=True,
                default="",
                help_text="The page subtitle as you'd like it to be seen by the public",
                max_length=255,
                verbose_name="subtitle",
            ),
        ),
        migrations.AlterField(
            model_name="post",
            name="body",
            field=wagtail.fields.StreamField(
                [
                    (
                        "overview",
                        wagtail.blocks.StreamBlock(
                            [
                                ("heading", wagtail.blocks.CharBlock(form_classname="full title")),
                                ("paragraph", wagtail.blocks.RichTextBlock()),
                                (
                                    "code",
                                    wagtail.blocks.StructBlock(
                                        [
                                            (
                                                "language",
                                                wagtail.blocks.CharBlock(help_text="The language of the code block"),
                                            ),
                                            (
                                                "source",
                                                wagtail.blocks.TextBlock(
                                                    help_text="The source code of the block", rows=8
                                                ),
                                            ),
                                        ],
                                        icon="code",
                                    ),
                                ),
                                ("image", cast.blocks.CastImageChooserBlock(template="cast/image/image.html")),
                                (
                                    "gallery",
                                    wagtail.blocks.StructBlock(
                                        [
                                            (
                                                "gallery",
                                                cast.blocks.GalleryBlock(cast.blocks.GalleryImageChooserBlock()),
                                            ),
                                            (
                                                "layout",
                                                wagtail.blocks.ChoiceBlock(
                                                    choices=[
                                                        ("default", "Web Component with Modal"),
                                                        ("htmx", "HTMX based layout"),
                                                    ]
                                                ),
                                            ),
                                        ]
                                    ),
                                ),
                                ("embed", wagtail.embeds.blocks.EmbedBlock()),
                                (
                                    "video",
                                    cast.blocks.VideoChooserBlock(icon="media", template="cast/video/video.html"),
                                ),
                                (
                                    "audio",
                                    cast.blocks.AudioChooserBlock(icon="media", template="cast/audio/audio.html"),
                                ),
                            ]
                        ),
                    ),
                    (
                        "detail",
                        wagtail.blocks.StreamBlock(
                            [
                                ("heading", wagtail.blocks.CharBlock(form_classname="full title")),
                                ("paragraph", wagtail.blocks.RichTextBlock()),
                                (
                                    "code",
                                    wagtail.blocks.StructBlock(
                                        [
                                            (
                                                "language",
                                                wagtail.blocks.CharBlock(help_text="The language of the code block"),
                                            ),
                                            (
                                                "source",
                                                wagtail.blocks.TextBlock(
                                                    help_text="The source code of the block", rows=8
                                                ),
                                            ),
                                        ],
                                        icon="code",
                                    ),
                                ),
                                ("image", cast.blocks.CastImageChooserBlock(template="cast/image/image.html")),
                                (
                                    "gallery",
                                    wagtail.blocks.StructBlock(
                                        [
                                            (
                                                "gallery",
                                                cast.blocks.GalleryBlock(cast.blocks.GalleryImageChooserBlock()),
                                            ),
                                            (
                                                "layout",
                                                wagtail.blocks.ChoiceBlock(
                                                    choices=[
                                                        ("default", "Web Component with Modal"),
                                                        ("htmx", "HTMX based layout"),
                                                    ]
                                                ),
                                            ),
                                        ]
                                    ),
                                ),
                                ("embed", wagtail.embeds.blocks.EmbedBlock()),
                                (
                                    "video",
                                    cast.blocks.VideoChooserBlock(icon="media", template="cast/video/video.html"),
                                ),
                                (
                                    "audio",
                                    cast.blocks.AudioChooserBlock(icon="media", template="cast/audio/audio.html"),
                                ),
                            ]
                        ),
                    ),
                ]
            ),
        ),
    ]
